@@ -21,7 +21,7 @@ from ironicclient.tests.functional import base
 class TestCase(base.FunctionalTestBase):
 
     def openstack(self, *args, **kwargs):
-        return self._ironic_osc(*args, **kwargs)
+        return self._ironic(cmd='openstack', *args, **kwargs)
 
     def get_opts(self, fields=None, output_format='json'):
         """Get options for OSC output fields format.
@@ -39,6 +39,18 @@ class TestCase(base.FunctionalTestBase):
     def construct_cmd(*parts):
         return ' '.join(str(x) for x in parts)
 
+    def assert_dict_is_subset(self, expected, actual):
+        """Check if expected keys/values exist in actual response body.
+
+        Check if the expected keys and values are in the actual response body.
+
+        :param expected: dict of key-value pairs that are expected to be in
+                         'actual' dict.
+        :param actual: dict of key-value pairs.
+        """
+        for key, value in expected.items():
+            self.assertEqual(value, actual[key])
+
     def node_create(self, driver='fake', name=None, params=''):
         """Create baremetal node and add cleanup.
 
@@ -284,3 +296,28 @@ class TestCase(base.FunctionalTestBase):
         chassis = self.openstack('baremetal chassis show {0} {1} {2}'
                                  .format(opts, uuid, params))
         return json.loads(chassis)
+
+    def driver_show(self, driver_name, fields=None, params=''):
+        """Show specified baremetal driver.
+
+        :param String driver_name: Name of the driver
+        :param List fields: List of fields to show
+        :param List params: Additional kwargs
+        :return: JSON object of driver
+        """
+        opts = self.get_opts(fields=fields)
+        driver = self.openstack('baremetal driver show {0} {1} {2}'
+                                .format(opts, driver_name, params))
+        return json.loads(driver)
+
+    def driver_list(self, fields=None, params=''):
+        """List baremetal drivers.
+
+        :param List fields: List of fields to show
+        :param String params: Additional kwargs
+        :return: list of JSON driver objects
+        """
+        opts = self.get_opts(fields=fields)
+        output = self.openstack('baremetal driver list {0} {1}'
+                                .format(opts, params))
+        return json.loads(output)
