@@ -13,6 +13,7 @@
 #    under the License.
 
 import ddt
+import json
 from tempest.lib.common.utils import data_utils
 
 from ironicclient.tests.functional.osc.v1 import base
@@ -26,26 +27,6 @@ class BaremetalNodeTests(base.TestCase):
         super(BaremetalNodeTests, self).setUp()
         self.node = self.node_create()
 
-    def test_warning_version_not_specified(self):
-        """Test API version warning is printed when API version unspecified.
-
-        A warning will appear for any invocation of the baremetal OSC plugin
-        without --os-baremetal-api-version specified. It's tested with a simple
-        node list command here.
-        """
-        output = self.openstack('baremetal node list', merge_stderr=True)
-        self.assertIn('the default will be the latest API version', output)
-
-    def test_no_warning_version_specified(self):
-        """Test API version warning is not printed when API version specified.
-
-        This warning should not appear when a user specifies the ironic API
-        version to use.
-        """
-        output = self.openstack('baremetal --os-baremetal-api-version=1.9 node'
-                                ' list', merge_stderr=True)
-        self.assertNotIn('the default will be the latest API version', output)
-
     def test_create_name_uuid(self):
         """Check baremetal node create command with name and UUID.
 
@@ -63,10 +44,25 @@ class BaremetalNodeTests(base.TestCase):
         self.assertEqual(node_info['name'], name)
         self.assertEqual(node_info['driver'], 'fake')
         self.assertEqual(node_info['maintenance'], False)
+        self.assertEqual(node_info['provision_state'], 'enroll')
         node_list = self.node_list()
         self.assertIn(uuid, [x['UUID'] for x in node_list])
         self.assertIn(name, [x['Name'] for x in node_list])
 
+    def test_create_old_api_version(self):
+        """Check baremetal node create command with name and UUID.
+
+        Test steps:
+        1) Create baremetal node in setUp.
+        2) Create one more baremetal node explicitly with old API version
+        3) Check that node successfully created.
+        """
+        node_info = self.node_create(
+            params='--os-baremetal-api-version 1.5')
+        self.assertEqual(node_info['driver'], 'fake')
+        self.assertEqual(node_info['maintenance'], False)
+        self.assertEqual(node_info['provision_state'], 'available')
+
     @ddt.data('name', 'uuid')
     def test_delete(self, key):
         """Check baremetal node delete command with name/UUID argument.
@@ -197,3 +193,38 @@ class BaremetalNodeTests(base.TestCase):
                                    ['maintenance_reason', 'maintenance'])
         self.assertIsNone(show_prop['maintenance_reason'])
         self.assertFalse(show_prop['maintenance'])
+
+    @ddt.data(
+        (50, '1'),
+        ('MAX', 'JBOD'),
+        (300, '6+0')
+    )
+    @ddt.unpack
+    def test_set_unset_target_raid_config(self, size, raid_level):
+        """Set and unset node target RAID config data.
+
+        Test steps:
+        1) Create baremetal node in setUp.
+        2) Set target RAID config data for the node
+        3) Check target_raid_config of node equals to expected value.
+        4) Unset target_raid_config data.
+        5) Check that target_raid_config data is empty.
+        """
+        min_version = '--os-baremetal-api-version 1.12'
+        argument_json = {"logical_disks":
+                         [{"size_gb": size, "raid_level": raid_level}]}
+        argument_string = json.dumps(argument_json)
+        self.openstack("baremetal node set --target-raid-config '{}' {} {}"
+                       .format(argument_string, self.node['uuid'],
+                               min_version))
+
+        show_prop = self.node_show(self.node['uuid'], ['target_raid_config'],
+                                   min_version)
+        self.assert_dict_is_subset(argument_json,
+                                   show_prop['target_raid_config'])
+
+        self.openstack("baremetal node unset --target-raid-config {} {}"
+                       .format(self.node['uuid'], min_version))
+        show_prop = self.node_show(self.node['uuid'], ['target_raid_config'],
+                                   min_version)
+        self.assertEqual({}, show_prop['target_raid_config'])
