@@ -183,6 +183,141 @@ class VersionNegotiationMixinTest(utils.BaseTestCase):
         self.assertEqual(1, mock_pvh.call_count)
         self.assertEqual(0, mock_save_data.call_count)
 
+    @mock.patch.object(filecache, 'save_data', autospec=True)
+    @mock.patch.object(http.VersionNegotiationMixin, '_parse_version_headers',
+                       autospec=True)
+    def test_negotiate_version_strict_version_comparison(self, mock_pvh,
+                                                         mock_save_data):
+        # Test version comparison with StrictVersion
+        max_ver = '1.10'
+        mock_pvh.return_value = ('1.2', max_ver)
+        mock_conn = mock.MagicMock()
+        self.test_object.os_ironic_api_version = '1.10'
+        result = self.test_object.negotiate_version(mock_conn, self.response)
+        self.assertEqual(max_ver, result)
+        self.assertEqual(1, mock_pvh.call_count)
+        host, port = http.get_server(self.test_object.endpoint)
+        mock_save_data.assert_called_once_with(host=host, port=port,
+                                               data=max_ver)
+
+    @mock.patch.object(filecache, 'save_data', autospec=True)
+    @mock.patch.object(http.VersionNegotiationMixin, '_make_simple_request',
+                       autospec=True)
+    @mock.patch.object(http.VersionNegotiationMixin, '_parse_version_headers',
+                       autospec=True)
+    def test_negotiate_version_server_user_latest(
+            self, mock_pvh, mock_msr, mock_save_data):
+        # have to retry with simple get
+        mock_pvh.side_effect = iter([(None, None), ('1.1', '1.99')])
+        mock_conn = mock.MagicMock()
+        self.test_object.api_version_select_state = 'user'
+        self.test_object.os_ironic_api_version = 'latest'
+        result = self.test_object.negotiate_version(mock_conn, None)
+        self.assertEqual(http.LATEST_VERSION, result)
+        self.assertEqual('negotiated',
+                         self.test_object.api_version_select_state)
+        self.assertEqual(http.LATEST_VERSION,
+                         self.test_object.os_ironic_api_version)
+
+        self.assertTrue(mock_msr.called)
+        self.assertEqual(2, mock_pvh.call_count)
+        self.assertEqual(1, mock_save_data.call_count)
+
+    @mock.patch.object(filecache, 'save_data', autospec=True)
+    @mock.patch.object(http.VersionNegotiationMixin, '_make_simple_request',
+                       autospec=True)
+    @mock.patch.object(http.VersionNegotiationMixin, '_parse_version_headers',
+                       autospec=True)
+    def test_negotiate_version_server_user_list(
+            self, mock_pvh, mock_msr, mock_save_data):
+        # have to retry with simple get
+        mock_pvh.side_effect = iter([(None, None), ('1.1', '1.26')])
+        mock_conn = mock.MagicMock()
+        self.test_object.api_version_select_state = 'user'
+        self.test_object.os_ironic_api_version = ['1.1', '1.6', '1.25',
+                                                  '1.26', '1.26.1', '1.27',
+                                                  '1.30']
+        result = self.test_object.negotiate_version(mock_conn, self.response)
+        self.assertEqual('1.26', result)
+        self.assertEqual('negotiated',
+                         self.test_object.api_version_select_state)
+        self.assertEqual('1.26',
+                         self.test_object.os_ironic_api_version)
+
+        self.assertTrue(mock_msr.called)
+        self.assertEqual(2, mock_pvh.call_count)
+        self.assertEqual(1, mock_save_data.call_count)
+
+    @mock.patch.object(filecache, 'save_data', autospec=True)
+    @mock.patch.object(http.VersionNegotiationMixin, '_make_simple_request',
+                       autospec=True)
+    @mock.patch.object(http.VersionNegotiationMixin, '_parse_version_headers',
+                       autospec=True)
+    def test_negotiate_version_server_user_list_fails_nomatch(
+            self, mock_pvh, mock_msr, mock_save_data):
+        # have to retry with simple get
+        mock_pvh.side_effect = iter([(None, None), ('1.2', '1.26')])
+        mock_conn = mock.MagicMock()
+        self.test_object.api_version_select_state = 'user'
+        self.test_object.os_ironic_api_version = ['1.39', '1.1']
+        self.assertRaises(
+            exc.UnsupportedVersion,
+            self.test_object.negotiate_version,
+            mock_conn, self.response)
+        self.assertEqual('user',
+                         self.test_object.api_version_select_state)
+        self.assertEqual(['1.39', '1.1'],
+                         self.test_object.os_ironic_api_version)
+        self.assertEqual(2, mock_pvh.call_count)
+        self.assertEqual(0, mock_save_data.call_count)
+
+    @mock.patch.object(filecache, 'save_data', autospec=True)
+    @mock.patch.object(http.VersionNegotiationMixin, '_make_simple_request',
+                       autospec=True)
+    @mock.patch.object(http.VersionNegotiationMixin, '_parse_version_headers',
+                       autospec=True)
+    def test_negotiate_version_server_user_list_single_value(
+            self, mock_pvh, mock_msr, mock_save_data):
+        # have to retry with simple get
+        mock_pvh.side_effect = iter([(None, None), ('1.1', '1.26')])
+        mock_conn = mock.MagicMock()
+        self.test_object.api_version_select_state = 'user'
+        # NOTE(TheJulia): Lets test this value explicitly because the
+        # minor number is actually the same.
+        self.test_object.os_ironic_api_version = ['1.01']
+        result = self.test_object.negotiate_version(mock_conn, None)
+        self.assertEqual('1.1', result)
+        self.assertEqual('negotiated',
+                         self.test_object.api_version_select_state)
+        self.assertEqual('1.1',
+                         self.test_object.os_ironic_api_version)
+        self.assertTrue(mock_msr.called)
+        self.assertEqual(2, mock_pvh.call_count)
+        self.assertEqual(1, mock_save_data.call_count)
+
+    @mock.patch.object(filecache, 'save_data', autospec=True)
+    @mock.patch.object(http.VersionNegotiationMixin, '_make_simple_request',
+                       autospec=True)
+    @mock.patch.object(http.VersionNegotiationMixin, '_parse_version_headers',
+                       autospec=True)
+    def test_negotiate_version_server_user_list_fails_latest(
+            self, mock_pvh, mock_msr, mock_save_data):
+        # have to retry with simple get
+        mock_pvh.side_effect = iter([(None, None), ('1.1', '1.2')])
+        mock_conn = mock.MagicMock()
+        self.test_object.api_version_select_state = 'user'
+        self.test_object.os_ironic_api_version = ['1.01', 'latest']
+        self.assertRaises(
+            ValueError,
+            self.test_object.negotiate_version,
+            mock_conn, self.response)
+        self.assertEqual('user',
+                         self.test_object.api_version_select_state)
+        self.assertEqual(['1.01', 'latest'],
+                         self.test_object.os_ironic_api_version)
+        self.assertEqual(2, mock_pvh.call_count)
+        self.assertEqual(0, mock_save_data.call_count)
+
     def test_get_server(self):
         host = 'ironic-host'
         port = '6385'
@@ -382,9 +517,10 @@ class HttpClientTest(utils.BaseTestCase):
         client = http.HTTPClient('http://localhost/')
         kwargs = {'headers': {'foo-header': 'bar-header'},
                   'body': '{"password": "foo"}'}
-        client.log_curl_request('foo', 'http://127.0.0.1', kwargs)
+        client.log_curl_request('foo', '/v1/nodes', kwargs)
         expected_log = ("curl -i -X foo -H 'foo-header: bar-header' "
-                        "-d '{\"password\": \"***\"}' http://127.0.0.1")
+                        "-d '{\"password\": \"***\"}' "
+                        "http://localhost/v1/nodes")
         mock_log.assert_called_once_with(expected_log)
 
     @mock.patch.object(http.LOG, 'debug', autospec=True)
@@ -538,6 +674,23 @@ class SessionClientTest(utils.BaseTestCase):
     def test_endpoint_override_not_valid(self):
         self._test_endpoint_override(True)
 
+    def test_make_simple_request(self):
+        session = mock.Mock(spec=['request'])
+
+        client = _session_client(session=session,
+                                 endpoint_override='http://127.0.0.1')
+        res = client._make_simple_request(session, 'GET', 'url')
+
+        session.request.assert_called_once_with(
+            'url', 'GET', raise_exc=False,
+            endpoint_filter={
+                'interface': 'publicURL',
+                'service_type': 'baremetal',
+                'region_name': ''
+            },
+            user_agent=http.USER_AGENT)
+        self.assertEqual(res, session.request.return_value)
+
 
 @mock.patch.object(time, 'sleep', lambda *_: None)
 class RetriesTestCase(utils.BaseTestCase):
