@@ -139,6 +139,28 @@ class UtilsTest(test_utils.BaseTestCase):
         self.assertRaises(exc.CommandError, utils.check_for_invalid_fields,
                           ['a', 'd'], ['a', 'b', 'c'])
 
+    def test_convert_list_props_to_comma_separated_strings(self):
+        data = {'prop1': 'val1',
+                'prop2': ['item1', 'item2', 'item3']}
+        result = utils.convert_list_props_to_comma_separated(data)
+        self.assertEqual('val1', result['prop1'])
+        self.assertEqual('item1, item2, item3', result['prop2'])
+
+    def test_convert_list_props_to_comma_separated_mix(self):
+        data = {'prop1': 'val1',
+                'prop2': [1, 2.5, 'item3']}
+        result = utils.convert_list_props_to_comma_separated(data)
+        self.assertEqual('val1', result['prop1'])
+        self.assertEqual('1, 2.5, item3', result['prop2'])
+
+    def test_convert_list_props_to_comma_separated_partial(self):
+        data = {'prop1': [1, 2, 3],
+                'prop2': [1, 2.5, 'item3']}
+        result = utils.convert_list_props_to_comma_separated(
+            data, props=['prop2'])
+        self.assertEqual([1, 2, 3], result['prop1'])
+        self.assertEqual('1, 2.5, item3', result['prop2'])
+
 
 class CommonParamsForListTest(test_utils.BaseTestCase):
     def setUp(self):
@@ -230,7 +252,7 @@ class CommonFiltersTest(test_utils.BaseTestCase):
         self.assertEqual(['fields=a,b,c'], result)
 
 
-@mock.patch.object(subprocess, 'Popen')
+@mock.patch.object(subprocess, 'Popen', autospec=True)
 class MakeConfigDriveTest(test_utils.BaseTestCase):
 
     def setUp(self):
@@ -256,14 +278,14 @@ class MakeConfigDriveTest(test_utils.BaseTestCase):
                                            stdout=subprocess.PIPE)
         fake_process.communicate.assert_called_once_with()
 
-    @mock.patch.object(os, 'access')
+    @mock.patch.object(os, 'access', autospec=True)
     def test_make_configdrive_non_readable_dir(self, mock_access, mock_popen):
         mock_access.return_value = False
         self.assertRaises(exc.CommandError, utils.make_configdrive, 'fake-dir')
         mock_access.assert_called_once_with('fake-dir', os.R_OK)
         self.assertFalse(mock_popen.called)
 
-    @mock.patch.object(os, 'access')
+    @mock.patch.object(os, 'access', autospec=True)
     def test_make_configdrive_oserror(self, mock_access, mock_popen):
         mock_access.return_value = True
         mock_popen.side_effect = OSError('boom')
@@ -274,7 +296,7 @@ class MakeConfigDriveTest(test_utils.BaseTestCase):
                                            stderr=subprocess.PIPE,
                                            stdout=subprocess.PIPE)
 
-    @mock.patch.object(os, 'access')
+    @mock.patch.object(os, 'access', autospec=True)
     def test_make_configdrive_non_zero_returncode(self, mock_access,
                                                   mock_popen):
         fake_process = mock.Mock(returncode=123)
